pub struct ControlPlane { /* private fields */ }Expand description
Control plane server that accepts tunnel client connections via mTLS
Implementations
Sourceimpl ControlPlane
impl ControlPlane
pub fn new( router: Arc<Router>, tls_acceptor: TlsAcceptor, dns_provider: Arc<dyn DnsProvider>, base_domain: String, response_registry: ResponseRegistry, tcp_plane: Arc<TcpPlane>, tcp_registry: TcpConnectionRegistry, ) -> Arc<Self>
Sourcepub async fn run(self: Arc<Self>, addr: SocketAddr) -> Result<()>
pub async fn run(self: Arc<Self>, addr: SocketAddr) -> Result<()>
Start listening for tunnel client connections
Sourcepub async fn run_with_listener(
self: Arc<Self>,
listener: TcpListener,
) -> Result<()>
pub async fn run_with_listener( self: Arc<Self>, listener: TcpListener, ) -> Result<()>
Start accepting connections from a pre-bound listener
This is useful for testing where the caller wants to bind to an ephemeral port and get the actual address before starting the server.